Erc4626Subcommand

Enum Erc4626Subcommand 

pub enum Erc4626Subcommand {
Show 19 variants Info { vault: NameOrAddress, human: bool, block: Option<BlockId>, rpc: RpcOpts, }, Position { vault: NameOrAddress, owner: NameOrAddress, human: bool, block: Option<BlockId>, rpc: RpcOpts, }, Check { vault: NameOrAddress, account: Option<NameOrAddress>, block: Option<BlockId>, rpc: RpcOpts, }, Asset { vault: NameOrAddress, block: Option<BlockId>, rpc: RpcOpts, }, TotalAssets { vault: NameOrAddress, block: Option<BlockId>, rpc: RpcOpts, }, ConvertToShares { vault: NameOrAddress, assets: U256, block: Option<BlockId>, rpc: RpcOpts, }, ConvertToAssets { vault: NameOrAddress, shares: U256, block: Option<BlockId>, rpc: RpcOpts, }, MaxDeposit { vault: NameOrAddress, receiver: NameOrAddress, block: Option<BlockId>, rpc: RpcOpts, }, PreviewDeposit { vault: NameOrAddress, assets: U256, block: Option<BlockId>, rpc: RpcOpts, }, Deposit { vault: NameOrAddress, assets: U256, receiver: NameOrAddress, send_tx: SendTxOpts, tx: TxParams, }, MaxMint { vault: NameOrAddress, receiver: NameOrAddress, block: Option<BlockId>, rpc: RpcOpts, }, PreviewMint { vault: NameOrAddress, shares: U256, block: Option<BlockId>, rpc: RpcOpts, }, Mint { vault: NameOrAddress, shares: U256, receiver: NameOrAddress, send_tx: SendTxOpts, tx: TxParams, }, MaxWithdraw { vault: NameOrAddress, owner: NameOrAddress, block: Option<BlockId>, rpc: RpcOpts, }, PreviewWithdraw { vault: NameOrAddress, assets: U256, block: Option<BlockId>, rpc: RpcOpts, }, Withdraw { vault: NameOrAddress, assets: U256, receiver: NameOrAddress, owner: NameOrAddress, send_tx: SendTxOpts, tx: TxParams, }, MaxRedeem { vault: NameOrAddress, owner: NameOrAddress, block: Option<BlockId>, rpc: RpcOpts, }, PreviewRedeem { vault: NameOrAddress, shares: U256, block: Option<BlockId>, rpc: RpcOpts, }, Redeem { vault: NameOrAddress, shares: U256, receiver: NameOrAddress, owner: NameOrAddress, send_tx: SendTxOpts, tx: TxParams, },
}
Interact with synchronous ERC-4626 tokenized vaults.

Variants



Info

Show vault, asset, and exchange-rate information

Example:

$ cast erc4626 info 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB --human \
    --block 25519075 --rpc-url https://ethereum.reth.rs/rpc

Output:

Vault                0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB
Name                 Steakhouse USDC
Symbol               steakUSDC
Decimals             18
Asset                0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48
Asset name           USD Coin
Asset symbol         USDC
Asset decimals       6
Total assets         95183395.377893 USDC
Total supply         84037200.060143388288943211 steakUSDC
Assets per share     1.132634 USDC
Shares per asset     0.882897731163608580 steakUSDC

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

human: bool

Use formatted token amounts in text output.

block: Option<BlockId>

The block height to query at.



Position

Show an account’s shares, asset value, and withdrawal limits

Example:

$ cast erc4626 position 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    0x255c7705E8bb334dfCaE438197f7c4297988085A --human --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

Vault                0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB
Owner                0x255c7705e8BB334DfCae438197f7C4297988085a
Asset                0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48
Share symbol         steakUSDC
Share decimals       18
Asset symbol         USDC
Asset decimals       6
Share balance        35733.949295544029939485 steakUSDC
Assets equivalent    40473.486378 USDC
Max withdraw         40473.486378 USDC
Max redeem           35733.949295417417957447 steakUSDC

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

owner: NameOrAddress

The owner of the vault shares.

human: bool

Use formatted token amounts in text output.

block: Option<BlockId>

The block height to query at.



Check

Probe synchronous ERC-4626 interface compatibility

Example:

$ cast erc4626 check 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    --account 0x255c7705E8bb334dfCaE438197f7c4297988085A --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

Vault                0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB
Account              0x255c7705e8BB334DfCae438197f7C4297988085a
Note: This probes read-call behavior only; it does not prove state-changing selector coverage or semantic ERC-4626 compliance.
PASS contract code            contract bytecode is present
PASS asset()                  returned 0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48
PASS asset contract           underlying asset bytecode is present
PASS asset balanceOf(address) call succeeded
PASS totalAssets()            call succeeded
PASS totalSupply()            call succeeded
PASS balanceOf(address)       call succeeded
PASS allowance(address,address) call succeeded
PASS convertToShares(0)       returned zero
PASS convertToAssets(0)       returned zero
PASS maxDeposit(address)      call succeeded
PASS previewDeposit(0)        returned zero
PASS maxMint(address)         call succeeded
PASS previewMint(0)           returned zero
PASS maxWithdraw(address)     call succeeded
PASS previewWithdraw(0)       returned zero
PASS maxRedeem(address)       call succeeded
PASS previewRedeem(0)         returned zero
PASS name()                   call succeeded
PASS symbol()                 call succeeded
PASS decimals()               call succeeded
Summary: 21 passed, 0 warnings, 0 failed

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

account: Option<NameOrAddress>

The account used for limit and balance probes.

block: Option<BlockId>

The block height to query at.



Asset

Query the vault’s underlying asset token

Example:

$ cast erc4626 asset 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    --block 25519075 --rpc-url https://ethereum.reth.rs/rpc

Output:

0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

block: Option<BlockId>

The block height to query at.



TotalAssets

Query the total amount of underlying assets managed by the vault

Example:

$ cast erc4626 total-assets 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    --block 25519075 --rpc-url https://ethereum.reth.rs/rpc

Output:

95183395377893 [9.518e13]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

block: Option<BlockId>

The block height to query at.



ConvertToShares

Convert an asset amount to the corresponding share amount

Example:

$ cast erc4626 convert-to-shares 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000 --block 25519075 --rpc-url https://ethereum.reth.rs/rpc

Output:

882897731163608580 [8.828e17]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

assets: U256

The amount of underlying assets.

block: Option<BlockId>

The block height to query at.



ConvertToAssets

Convert a share amount to the corresponding asset amount

Example:

$ cast erc4626 convert-to-assets 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000000000000000 --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

1132634 [1.132e6]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

shares: U256

The amount of vault shares.

block: Option<BlockId>

The block height to query at.



MaxDeposit

Query the maximum assets that may be deposited for a receiver

Example:

$ cast erc4626 max-deposit 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    0x255c7705E8bb334dfCaE438197f7c4297988085A --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

1002934816604622098 [1.002e18]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

receiver: NameOrAddress

The receiver of the resulting vault shares.

block: Option<BlockId>

The block height to query at.



PreviewDeposit

Preview the shares received by depositing an asset amount

Example:

$ cast erc4626 preview-deposit 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000 --block 25519075 --rpc-url https://ethereum.reth.rs/rpc

Output:

882897731163608580 [8.828e17]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

assets: U256

The amount of underlying assets.

block: Option<BlockId>

The block height to query at.



Deposit

Deposit assets into the vault

The vault must have sufficient allowance to spend the underlying asset.

Example:

$ cast erc4626 deposit 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000 $ACCOUNT --private-key $PRIVATE_KEY --async --rpc-url $ETH_RPC_URL

Output:

0x6f2a7e10f148a0ee81208cd8d7dee10cc33b5bdb739bfeef805dc68467e6db4e

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

assets: U256

The amount of underlying assets.

receiver: NameOrAddress

The receiver of the resulting vault shares.

send_tx: SendTxOpts


MaxMint

Query the maximum shares that may be minted for a receiver

Example:

$ cast erc4626 max-mint 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    0x255c7705E8bb334dfCaE438197f7c4297988085A --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

885488874085210715750045480687 [8.854e29]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

receiver: NameOrAddress

The receiver of the resulting vault shares.

block: Option<BlockId>

The block height to query at.



PreviewMint

Preview the assets required to mint a share amount

Example:

$ cast erc4626 preview-mint 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000000000000000 --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

1132635 [1.132e6]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

shares: U256

The amount of vault shares.

block: Option<BlockId>

The block height to query at.



Mint

Mint vault shares

The vault must have sufficient allowance to spend the underlying asset.

Example:

$ cast erc4626 mint 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000000000000000 $ACCOUNT --private-key $PRIVATE_KEY --async \
    --rpc-url $ETH_RPC_URL

Output:

0xa7c3b4e26a99e2cb422e2b36cffeae642a39f1d09f8f3454c9c2d4657ebb0491

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

shares: U256

The amount of vault shares.

receiver: NameOrAddress

The receiver of the resulting vault shares.

send_tx: SendTxOpts


MaxWithdraw

Query the maximum assets that an owner may withdraw

Example:

$ cast erc4626 max-withdraw 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    0x255c7705E8bb334dfCaE438197f7c4297988085A --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

40473486378 [4.047e10]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

owner: NameOrAddress

The owner of the vault shares.

block: Option<BlockId>

The block height to query at.



PreviewWithdraw

Preview the shares burned to withdraw an asset amount

Example:

$ cast erc4626 preview-withdraw 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000 --block 25519075 --rpc-url https://ethereum.reth.rs/rpc

Output:

882897731163608581 [8.828e17]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

assets: U256

The amount of underlying assets.

block: Option<BlockId>

The block height to query at.



Withdraw

Withdraw assets from the vault

Example:

$ cast erc4626 withdraw 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000 $ACCOUNT $ACCOUNT --private-key $PRIVATE_KEY --async \
    --rpc-url $ETH_RPC_URL

Output:

0x6d6d70151151f30aa13bdb4082ea7fd3e531193eebdfbb356586284cd0e6a8a2

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

assets: U256

The amount of underlying assets.

receiver: NameOrAddress

The receiver of the withdrawn assets.

owner: NameOrAddress

The owner of the vault shares.

send_tx: SendTxOpts


MaxRedeem

Query the maximum shares that an owner may redeem

Example:

$ cast erc4626 max-redeem 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    0x255c7705E8bb334dfCaE438197f7c4297988085A --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

35733949295417417957447 [3.573e22]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

owner: NameOrAddress

The owner of the vault shares.

block: Option<BlockId>

The block height to query at.



PreviewRedeem

Preview the assets received by redeeming a share amount

Example:

$ cast erc4626 preview-redeem 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000000000000000 --block 25519075 \
    --rpc-url https://ethereum.reth.rs/rpc

Output:

1132634 [1.132e6]

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

shares: U256

The amount of vault shares.

block: Option<BlockId>

The block height to query at.



Redeem

Redeem vault shares for assets

Example:

$ cast erc4626 redeem 0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB \
    1000000000000000000 $ACCOUNT $ACCOUNT --private-key $PRIVATE_KEY --async \
    --rpc-url $ETH_RPC_URL

Output:

0x304d463e4d33b462778a974d008cd1b9c4c109730ae6617d2815477b8aa7c03e

Fields

vault: NameOrAddress

The ERC-4626 vault contract address.

shares: U256

The amount of vault shares.

receiver: NameOrAddress

The receiver of the redeemed assets.

owner: NameOrAddress

The owner of the vault shares.

send_tx: SendTxOpts

Implementations

Source

impl Erc4626Subcommand

pub async fn run(self) -> Result<()>